NLSL: wstruct Struct Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Data Types List
- Data Types
- Data Fields

Public Attributes | List of all members
wstruct Struct Reference

## Public Attributes
Display * | dspy
Drawable | wndw
GC | gc
GC | gc1
GC | gc2
GC | gc3
Colormap | map
XPoint | xye [4096]
XPoint | xys [4096]
XPoint | ydif [4096]
float | ye [4096]
float | ys [4096]
float | xmin
float | xmax
float | xstep
float | ymin
float | ymax
int | indx
int | scrn
int | mode
unsigned int | fgnd
unsigned int | bgnd
int | flag
int | flag2
int | yzer
int | nx
int | ny
float | er
float | el
float | et
float | eb
int | led
int | red
int | bed
int | ted

## Detailed Description

Definition at line 57 of file pltx.c.

## Member Data Documentation

int wstruct::bed

Definition at line 74 of file pltx.c.

unsigned int wstruct::bgnd

Definition at line 69 of file pltx.c.

Display* wstruct::dspy

Definition at line 59 of file pltx.c.

float wstruct::eb

Definition at line 73 of file pltx.c.

float wstruct::el

Definition at line 73 of file pltx.c.

float wstruct::er

Definition at line 73 of file pltx.c.

float wstruct::et

Definition at line 73 of file pltx.c.

unsigned int wstruct::fgnd

Definition at line 69 of file pltx.c.

int wstruct::flag

Definition at line 70 of file pltx.c.

int wstruct::flag2

Definition at line 70 of file pltx.c.

GC wstruct::gc

Definition at line 61 of file pltx.c.

GC wstruct::gc1

Definition at line 61 of file pltx.c.

GC wstruct::gc2

Definition at line 61 of file pltx.c.

GC wstruct::gc3

Definition at line 61 of file pltx.c.

int wstruct::indx

Definition at line 66 of file pltx.c.

int wstruct::led

Definition at line 74 of file pltx.c.

Colormap wstruct::map

Definition at line 62 of file pltx.c.

int wstruct::mode

Definition at line 68 of file pltx.c.

int wstruct::nx

Definition at line 72 of file pltx.c.

int wstruct::ny

Definition at line 72 of file pltx.c.

int wstruct::red

Definition at line 74 of file pltx.c.

int wstruct::scrn

Definition at line 67 of file pltx.c.

int wstruct::ted

Definition at line 74 of file pltx.c.

Drawable wstruct::wndw

Definition at line 60 of file pltx.c.

float wstruct::xmax

Definition at line 65 of file pltx.c.

float wstruct::xmin

Definition at line 65 of file pltx.c.

float wstruct::xstep

Definition at line 65 of file pltx.c.

XPoint wstruct::xye[4096]

Definition at line 63 of file pltx.c.

XPoint wstruct::xys[4096]

Definition at line 63 of file pltx.c.

XPoint wstruct::ydif[4096]

Definition at line 63 of file pltx.c.

float wstruct::ye[4096]

Definition at line 64 of file pltx.c.

float wstruct::ymax

Definition at line 65 of file pltx.c.

float wstruct::ymin

Definition at line 65 of file pltx.c.

float wstruct::ys[4096]

Definition at line 64 of file pltx.c.

int wstruct::yzer

Definition at line 71 of file pltx.c.

The documentation for this struct was generated from the following file:

- pltx.c